@@ -37,16 +37,17 @@ setReplaceMethod("info", signature(x = "associations"),
 ## sort + unique
 ## since R 2.4.0 sort is a generic
 setMethod("sort", signature(x = "associations"),
-    function (x, decreasing = TRUE, na.last = NA, by = "support") {
+    function (x, decreasing = TRUE, na.last = NA, by = "support", ...) {
         if(length(x) == 0) return(x)
-        x[order(x@quality[[by]], na.last = na.last, decreasing = decreasing)]
+        x[order(x@quality[[by]], na.last = na.last, decreasing = decreasing, ...)]
     })
 
 ## SORT is just for backward compatibility and since 
 ## we want decreasing = TRUE   
 setMethod("SORT", signature(x = "associations"),
     function (x, by = "support", na.last = NA, decreasing = TRUE) {
-        sort(x, decreasing, na.last, by)
+        warning("arules: SORT is deprecated use sort instead.")
+	sort(x, decreasing, na.last, by)
     })
 
 
